@@ -1,5 +1,5 @@
 /*
-  $Id: check_user.c,v 1.1 1996/11/10 21:19:30 morgan Exp morgan $
+  $Id: check_user.c,v 1.1.1.1 1998/07/12 05:17:14 morgan Exp $
   
   This program was contributed by Shane Watts <shane@icarus.bofh.asn.au>
   slight modifications by AGM.
@@ -10,6 +10,9 @@
   check   account    required     pam_unix_acct.so
 
   $Log: check_user.c,v $
+  Revision 1.1.1.1  1998/07/12 05:17:14  morgan
+  Linux PAM sources pre-0.66
+
   Revision 1.1  1996/11/10 21:19:30  morgan
   Initial revision
 
