@@ -1,7 +1,13 @@
 /*
- * $Id: xsh.c,v 1.4 1996/11/10 21:09:45 morgan Exp morgan $
+ * $Id: xsh.c,v 1.2 1999/11/08 05:39:53 morgan Exp $
  *
  * $Log: xsh.c,v $
+ * Revision 1.2  1999/11/08 05:39:53  morgan
+ * removed void main def which was making gcc complain
+ *
+ * Revision 1.1.1.1  1998/07/12 05:17:14  morgan
+ * Linux PAM sources pre-0.66
+ *
  * Revision 1.4  1996/11/10 21:09:45  morgan
  * no gcc warnings
  *
@@ -44,7 +50,7 @@ static struct pam_conv conv = {
 
 /* ------- the application itself -------- */
 
-void main(int argc, char **argv, char **envp)
+int main(int argc, char **argv, char **envp)
 {
      pam_handle_t *pamh=NULL;
      char *username=NULL;
