@@ -1,7 +1,7 @@
 /*
  * <security/_pam_types.h>
  *
- * $Id: _pam_types.h,v 1.4 1999/02/22 02:29:18 morgan Exp $
+ * $Id: _pam_types.h,v 1.5 1999/07/04 23:24:20 morgan Exp $
  *
  * This file defines all of the types common to the Linux-PAM library
  * applications and modules.
@@ -9,20 +9,6 @@
  * Note, the copyright+license information is at end of file.
  *
  * Created: 1996/3/5 by AGM
- *
- * $Log: _pam_types.h,v $
- * Revision 1.4  1999/02/22 02:29:18  morgan
- * fix(?) for strange glibc behavior wrt LOG_PRIV
- *
- * Revision 1.3  1998/12/27 04:06:48  morgan
- * retracted syslog functions.. PAM should not be trying to solve libc problems
- *
- * Revision 1.2  1998/07/12 05:57:18  morgan
- * update for systems not having LOG_AUTHPRIV syslog level
- *
- * Revision 1.1.1.1  1998/07/12 05:17:15  morgan
- * Linux PAM sources pre-0.66
- *
  */
 
 #ifndef _SECURITY__PAM_TYPES_H
@@ -225,14 +211,8 @@ extern int pam_fail_delay(pam_handle_t *pamh, unsigned int musec_delay);
 #define PAM_RADIO_TYPE          5        /* yes/no/maybe conditionals */
 
 /* This is for server client non-human interaction.. these are NOT
-   part of the X/Open PAM specification (yet although Vipin has hinted
-   that they may well be 1997/7/8) but are currently included for
-   exploritory reasons.  Basically, they are for the module to obtain a
-   binary chunk of data from the client (via the server).  Such data
-   is intercepted by the server and unpacked in preparation for the
-   module */
+   part of the X/Open PAM specification. */
 
-#define PAM_BINARY_MSG          6
 #define PAM_BINARY_PROMPT       7
 
 /* maximum size of messages/responses etc.. (these are mostly
@@ -259,10 +239,11 @@ struct pam_message {
 
    struct {
        u32 length;                         #  network byte order
-       unsigned char data[length];
+       unsigned char type;
+       unsigned char data[length-5];
    };
 
-   The 'libpam_client' library is designed around this flavor of
+   The 'libpamc' library is designed around this flavor of
    message and should be used to handle this flavor of msg_style.
    */
 
