@@ -1,9 +1,13 @@
 /* pam_item.c */
 
 /*
- * $Id: pam_item.c,v 1.2 1998/12/27 04:34:22 morgan Exp $
+ * $Id: pam_item.c,v 1.3 1999/11/08 05:41:05 morgan Exp $
  *
  * $Log: pam_item.c,v $
+ * Revision 1.3  1999/11/08 05:41:05  morgan
+ * pam_log - extra paranoia
+ * otherwise debugging changes
+ *
  * Revision 1.2  1998/12/27 04:34:22  morgan
  * reverting logging functions within libpam.  Gone are the externally
  * advertised API replaced by a more simple (libpam internal) one.
@@ -155,10 +159,11 @@ int pam_get_item (
 	*item = pamh->service_name;
 	break;
     case PAM_USER:
+	D(("returning user=%s", pamh->user));
 	*item = pamh->user;
 	break;
     case PAM_USER_PROMPT:
-	D(("returning user=%s", pamh->user));
+	D(("returning userprompt=%s", pamh->user));
 	*item = pamh->prompt;
 	break;
     case PAM_TTY:
