@@ -1,5 +1,5 @@
 /*
- * $Id: libpamc.h,v 1.3 1999/10/09 05:03:57 morgan Exp $
+ * $Id: libpamc.h,v 1.4 1999/12/13 04:56:37 morgan Exp $
  *
  * Copyright (c) Andrew G. Morgan <morgan@ftp.kernel.org>
  *
@@ -20,6 +20,8 @@
 #include <errno.h>
 #include <ctype.h>
 
+#define _PAMC_DEFAULT_TOP_FD  10
+
 struct pamc_handle_s {
     struct pamc_agent_s *current;
     struct pamc_agent_s *chain;
@@ -27,6 +29,7 @@ struct pamc_handle_s {
     int max_path;
     char **agent_paths;
     int combined_status;
+    int highest_fd_to_close;
 };
 
 typedef struct pamc_blocked_s {
