@@ -488,7 +488,6 @@ PAM_EXTERN int pam_sm_chauthtok(pam_handle_t *pamh, int flags,
     } else if (flags & PAM_UPDATE_AUTHTOK) {
         int retval;
         char *token1, *token2, *oldtoken;
-        const char *item;
         struct pam_message msg[1],*pmsg[1];
         struct pam_response *resp;
         const char *cracklib_dictpath = CRACKLIB_DICTPATH;
@@ -525,18 +524,21 @@ PAM_EXTERN int pam_sm_chauthtok(pam_handle_t *pamh, int flags,
          */
 
 	if (options.use_authtok == 1) {
-            retval = pam_get_item(pamh, PAM_AUTHTOK, (const void **) &item);
+	    const char *item = NULL;
+
+	    retval = pam_get_item(pamh, PAM_AUTHTOK, (const void **) &item);
 	    if (retval != PAM_SUCCESS) {
 		/* very strange. */
 		_pam_log(LOG_ALERT
 			,"pam_get_item returned error to pam_cracklib"
 			);
 	    } else if (item != NULL) {      /* we have a password! */
-		token1 = item;
+		token1 = x_strdup(item);
 		item = NULL;
 	    } else {
 		retval = PAM_AUTHTOK_RECOVER_ERR;         /* didn't work */
 	    }
+
 	} else {
             /* Prepare to ask the user for the first time */
             memset(prompt,0,sizeof(prompt));
@@ -670,23 +672,25 @@ PAM_EXTERN int pam_sm_chauthtok(pam_handle_t *pamh, int flags,
              * we store this password as an item
              */
 
-            retval = pam_set_item(pamh, PAM_AUTHTOK, token1);
-            /* clean it up */
-            token1 = _pam_delete(token1);
-            token2 = _pam_delete(token2);
-            if (
-                (retval != PAM_SUCCESS) ||
-                (
-                 (
-                    retval = pam_get_item(pamh, PAM_AUTHTOK, (const void **)&item)
-                 ) != PAM_SUCCESS
-                )
-               ) {
+	    {
+		const char *item = NULL;
+
+		retval = pam_set_item(pamh, PAM_AUTHTOK, token1);
+
+		/* clean up */
+		token1 = _pam_delete(token1);
+		token2 = _pam_delete(token2);
+
+		if ( (retval != PAM_SUCCESS) ||
+		     ((retval = pam_get_item(pamh, PAM_AUTHTOK,
+					     (const void **)&item)
+			 ) != PAM_SUCCESS) ) {
                     _pam_log(LOG_CRIT, "error manipulating password");
                     continue;
-            }
-            item = NULL;                 /* break link to password */
-            return PAM_SUCCESS;
+		}
+		item = NULL;                 /* break link to password */
+		return PAM_SUCCESS;
+	    }
         }
         
         } while (options.retry_times--);
