@@ -1,29 +1,20 @@
 /* pam_lastlog module */
 
 /*
- * $Id: pam_lastlog.c,v 1.1.1.1 1998/07/12 05:17:17 morgan Exp $
+ * $Id: pam_lastlog.c,v 1.2 1999/07/08 05:01:51 morgan Exp $
  *
- * Written by Andrew Morgan <morgan@parc.power.net> 1996/3/11
+ * Written by Andrew Morgan <morgan@linux.kernel.org> 1996/3/11
  *
  * This module does the necessary work to display the last login
  * time+date for this user, it then updates this entry for the
  * present (login) service.
- *
- * $Log: pam_lastlog.c,v $
- * Revision 1.1.1.1  1998/07/12 05:17:17  morgan
- * Linux PAM sources pre-0.66
- *
- * Revision 1.3  1997/04/05 06:18:21  morgan
- * removed xstrdup - unused
- *
- * Revision 1.2  1997/02/15 17:18:21  morgan
- * removed fixed buffer in logging
- *
- * Revision 1.1  1997/01/04 20:29:28  morgan
- * Initial revision
- *
  */
 
+#ifdef linux
+# define _GNU_SOURCE
+# include <features.h>
+#endif
+
 #include <fcntl.h>
 #include <time.h>
 #ifdef HAVE_UTMP_H
