@@ -1,5 +1,5 @@
 /*
- * $Id: pwdb_chkpwd.c,v 1.2 1999/07/08 05:02:03 morgan Exp $
+ * $Id: pwdb_chkpwd.c,v 1.3 1999/11/22 02:53:46 morgan Exp $
  *
  * This program is designed to run setuid(root) or with sufficient
  * privilege to read all of the unix password databases. It is designed
@@ -11,21 +11,10 @@
  *
  * Copyright information is located at the end of the file.
  *
- * $Log: pwdb_chkpwd.c,v $
- * Revision 1.2  1999/07/08 05:02:03  morgan
- * glibc fixes (Thorsten Kukuk, Adam J. Richter)
- *
- * Revision 1.1.1.1  1998/07/12 05:17:17  morgan
- * Linux PAM sources pre-0.66
- *
- * Revision 1.1  1997/02/15 17:26:18  morgan
- * Initial revision
- *
- * Revision 1.1  1996/11/10 21:20:51  morgan
- * Initial revision
- *
  */
 
+#define _BSD_SOURCE
+
 #ifdef linux
 # define _GNU_SOURCE
 # include <features.h>
@@ -60,6 +49,7 @@ static void _log_err(int err, const char *format, ...)
     closelog();
 }
 
+#define PWDB_NO_MD_COMPAT
 #include "pam_unix_md.-c"
 
 static int _unix_verify_passwd(const char *salt, const char *p)
