@@ -20,7 +20,7 @@
 #include <syslog.h>
 #include <stdarg.h>
 #include <pwd.h>
-#include <strings.h>
+#include <string.h>
 
 #define PAM_SM_AUTH
 
