@@ -1,12 +1,13 @@
 /* pam_userdb module */
  
 /*
- * $Id: pam_userdb.c,v 1.2 1999/10/09 05:13:20 morgan Exp $
+ * $Id: pam_userdb.c,v 1.3 1999/11/22 02:19:01 morgan Exp $
  * Written by Cristian Gafton <gafton@redhat.com> 1996/09/10
  * See the end of the file for Copyright Information
  */
 
 #define _GNU_SOURCE
+#define _BSD_SOURCE
 
 #include <features.h>
 #include <stdlib.h>
@@ -21,8 +22,12 @@
 
 #include "pam_userdb.h"
 
-#define DB_DBM_HSEARCH    1 /* use the dbm interface */
-#include <db.h>
+#ifdef USE_NDBM_H
+# include <ndbm.h>
+#else /* USE_NDBM_H */
+# define DB_DBM_HSEARCH    1 /* use the dbm interface */
+# include <db.h>
+#endif /* USE_NDBM_H */
 
 /*
  * here, we make a definition for the externally accessible function
@@ -96,29 +101,39 @@ static int user_lookup(const char *user, const char *pass)
     /* Open the DB file. */
     dbm = dbm_open(database, O_RDONLY, 0644);
     if (dbm == NULL) {
-	_pam_log(LOG_ERR, "user_lookup: could not open database `%s'", database);
+	_pam_log(LOG_ERR, "user_lookup: could not open database `%s'",
+		 database);
 	return -2;
     }
 
     if (ctrl &PAM_DUMP_ARG) {
 	_pam_log(LOG_INFO, "Database dump:");
-	for (key = dbm_firstkey(dbm);  key.dptr != NULL; key = dbm_nextkey(dbm)) {
+	for (key = dbm_firstkey(dbm);  key.dptr != NULL;
+	     key = dbm_nextkey(dbm)) {
 	    data = dbm_fetch(dbm, key);
 	    _pam_log(LOG_INFO, "key[len=%d] = `%s', data[len=%d] = `%s'",
 		     key.dsize, key.dptr, data.dsize, data.dptr);
 	}
     } 
     /* do some more init work */
+
     memset(&key, 0, sizeof(key));
     memset(&data, 0, sizeof(data));
-    key.dptr = user;
+    key.dptr = x_strdup(user);
     key.dsize = strlen(user);
-    
-    data = dbm_fetch(dbm, key);  
+    user = NULL;
+
+    if (key.dptr) {
+	data = dbm_fetch(dbm, key);
+	memset(key.dptr, 0, key.dsize);
+	free(key.dptr);
+    }
+
     if (ctrl & PAM_DEBUG_ARG) {
 	_pam_log(LOG_INFO, "password in database is [%p]`%s', len is %d",
 		 data.dptr, (char *) data.dptr, data.dsize);
     }
+
     if (data.dptr != NULL) {
 	int compare = 0;
 	/* bingo, got it */
@@ -133,16 +148,15 @@ static int user_lookup(const char *user, const char *pass)
 	    return -1; /* wrong */
     } else {
 	if (ctrl & PAM_DEBUG_ARG) {    
-	    _pam_log(LOG_INFO, "error returned by dbm_fetch: %s", strerror(errno));
+	    _pam_log(LOG_INFO, "error returned by dbm_fetch: %s",
+		     strerror(errno));
 	}
 	dbm_close(dbm);
-	/* prolly we should chec dbm_error() here */
+	/* probably we should check dbm_error() here */
 	return 1; /* not found */
     }
-	    
-    if (dbm != NULL)
-	dbm_close(dbm);
-    /* we don't know what the heck happend */
+
+    /* NOT REACHED */
     return -2;
 }
 
@@ -176,7 +190,7 @@ int pam_sm_authenticate(pam_handle_t *pamh, int flags,
      }
      
      /* Get the password */
-     retval = pam_get_item(pamh, PAM_AUTHTOK, &password);
+     retval = pam_get_item(pamh, PAM_AUTHTOK, (const void **)&password);
      if (retval != PAM_SUCCESS) {
 	 _pam_log(LOG_ERR, "Could not retrive user's password");
 	 return -2;
@@ -194,7 +208,9 @@ int pam_sm_authenticate(pam_handle_t *pamh, int flags,
 	     return PAM_SERVICE_ERR;    
 	 case -1:
 	     /* incorrect password */
-	     _pam_log(LOG_WARNING, "user `%s' denied access (incorrect password)", username);
+	     _pam_log(LOG_WARNING,
+		      "user `%s' denied access (incorrect password)",
+		      username);
 	     return PAM_AUTH_ERR;
 	 case 1:
 	     /* the user does not exist in the database */
@@ -208,10 +224,12 @@ int pam_sm_authenticate(pam_handle_t *pamh, int flags,
 	     return PAM_SUCCESS;
 	 default:
 	     /* we don't know anything about this return value */
-	     _pam_log(LOG_ERR, "internal module error (retval = %d, user = `%s'",
+	     _pam_log(LOG_ERR,
+		      "internal module error (retval = %d, user = `%s'",
 		      retval, username);
 	     return PAM_SERVICE_ERR;
      }
+
      /* should not be reached */
      return PAM_IGNORE;
 }
